==> kipi-plugins-trinity_3.5.13.2.orig.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/rawconverter/clistviewitem.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2003-10-25
 * Description : Raw file list view used into batch converter.
 *
 * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef CLISTVIEWITEM_H
#define CLISTVIEWITEM_H

// TQt includes.

#include <tqstring.h>
#include <tqpainter.h>

// KDE includes.

#include <klistview.h>

class TQPixmap;

namespace KIPIRawConverterPlugin
{

class CListViewItem;

struct RawItem 
{
    TQString        src;
    TQString        dest;
    TQString        directory;
    TQString        identity;

    CListViewItem *viewItem;
};

class CListViewItem : public KListViewItem
{

public:

    struct RawItem *rawItem;

public:

    CListViewItem(KListView *view, const TQPixmap& pixmap, 
                  RawItem *item, TQListViewItem *after)
                : KListViewItem(view, after), rawItem(item) 
    {
         rawItem->viewItem = this;
         setThumbnail(pixmap);
         setText(1, rawItem->src);
         setText(2, rawItem->dest);
         setEnabled(true);
    }

    ~CListViewItem(){}

    void setThumbnail(const TQPixmap& pixmap) 
    {
        setPixmap(0, pixmap);
    }

    void setEnabled(bool d)    
    {
        m_enabled = d;
        repaint();
    }

    bool isEnabled(void)    
    {
        return m_enabled;
    }
    
protected:

    void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment)
    {
        if (m_enabled)
        {
            KListViewItem::paintCell(p, cg, column, width, alignment);
        }
        else
        {
            TQColorGroup _cg( cg );
            TQColor c = _cg.text();
            _cg.setColor( TQColorGroup::Text, TQt::gray );
            KListViewItem::paintCell( p, _cg, column, width, alignment );
            _cg.setColor( TQColorGroup::Text, c );
        }
    }

private: 

    bool m_enabled;
};

} // NameSpace KIPIRawConverterPlugin

#endif /* CLISTVIEWITEM_H */

==> kipi-plugins-trinity_14.2.0~pre111.orig.tar.xz: kipi-plugins-trinity-14.2.0~pre111+0a125237/kipi-plugins/rawconverter/clistviewitem.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2003-10-25
 * Description : Raw file list view used into batch converter.
 *
 * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef CLISTVIEWITEM_H
#define CLISTVIEWITEM_H

// TQt includes.

#include <tqstring.h>
#include <tqpainter.h>

// KDE includes.

#include <tdelistview.h>

class TQPixmap;

namespace KIPIRawConverterPlugin
{

class CListViewItem;

struct RawItem 
{
    TQString        src;
    TQString        dest;
    TQString        directory;
    TQString        identity;

    CListViewItem *viewItem;
};

class CListViewItem : public TDEListViewItem
{

public:

    struct RawItem *rawItem;

public:

    CListViewItem(TDEListView *view, const TQPixmap& pixmap, 
                  RawItem *item, TQListViewItem *after)
                : TDEListViewItem(view, after), rawItem(item) 
    {
         rawItem->viewItem = this;
         setThumbnail(pixmap);
         setText(1, rawItem->src);
         setText(2, rawItem->dest);
         setEnabled(true);
    }

    ~CListViewItem(){}

    void setThumbnail(const TQPixmap& pixmap) 
    {
        setPixmap(0, pixmap);
    }

    void setEnabled(bool d)    
    {
        m_enabled = d;
        repaint();
    }

    bool isEnabled(void)    
    {
        return m_enabled;
    }
    
protected:

    void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment)
    {
        if (m_enabled)
        {
            TDEListViewItem::paintCell(p, cg, column, width, alignment);
        }
        else
        {
            TQColorGroup _cg( cg );
            TQColor c = _cg.text();
            _cg.setColor( TQColorGroup::Text, TQt::gray );
            TDEListViewItem::paintCell( p, _cg, column, width, alignment );
            _cg.setColor( TQColorGroup::Text, c );
        }
    }

private: 

    bool m_enabled;
};

} // NameSpace KIPIRawConverterPlugin

#endif /* CLISTVIEWITEM_H */
